Module handler

Module handler 

The raw handler and host backend interfaces.

Traits

Allocator
An implementation of Allocator can allocate, grow, shrink, and deallocate arbitrary blocks of data described via Layout.
HostBackend
A host backend for the handler.
RawHandler
A handler for an account.